@@ -18,6 +18,7 @@ class QGroupBox;
 class QLabel;
 class QRadioButton;
 class QCheckBox;
+class QLineEdit;
 class KComboBox;
 class KLineEdit;
 
@@ -25,6 +26,11 @@ class UMLObject;
 class UMLWidget;
 class ObjectWidget;
 class UMLDoc;
+class UMLArtifactTypeWidget;
+class UMLObjectNameWidget;
+class UMLPackageWidget;
+class UMLStereotypeWidget;
+class VisibilityEnumWidget;
 
 /**
  * Displays properties of a UMLObject in a dialog box.  This is not usually directly
@@ -70,7 +76,7 @@ public:
      */
     ~ClassGeneralPage();
 
-    void updateObject();
+    void apply();
 
 private:
     UMLObject * m_pObject;
@@ -78,18 +84,19 @@ private:
     UMLWidget * m_pInstanceWidget;
     UMLDoc * m_pUmldoc;
 
-    QGroupBox * m_pButtonGB;
-    QLabel * m_pNameL, * m_pInstanceL, * m_pStereoTypeL, * m_pPackageL;
-    KLineEdit * m_pClassNameLE, * m_pInstanceLE, * m_pPackageLE;
-    KComboBox * m_pStereoTypeCB, * m_pPackageCB ;
-    QRadioButton * m_pPublicRB, * m_pPrivateRB, * m_pProtectedRB, * m_pImplementationRB;
+    QLabel * m_pInstanceL, * m_pStereoTypeL;
     QCheckBox * m_pMultiCB, * m_pDrawActorCB, * m_pAbstractCB, * m_pDeconCB;
-    DocumentationWidget *m_docWidget;
-    QGroupBox * m_pDrawAsGB;
-    QRadioButton * m_pDefaultRB, * m_pFileRB, * m_pLibraryRB, * m_pTableRB;
     QCheckBox * m_pExecutableCB;
+    DocumentationWidget *m_docWidget;
+    UMLObjectNameWidget *m_nameWidget;
+    UMLObjectNameWidget *m_instanceNameWidget;
+    UMLStereotypeWidget *m_stereotypeWidget;
+    UMLPackageWidget *m_packageWidget;
+    UMLArtifactTypeWidget *m_artifactTypeWidget;
+    VisibilityEnumWidget *m_visibilityEnumWidget;
 
     void insertStereotypesSorted(const QString& type);
+    void setInstanceWidgetNameIfApplicable(const QString& name) const;
 
 public slots:
 
