@@ -13,6 +13,7 @@
 
 // app includes
 #include "debug_utils.h"
+#include "dialog_utils.h"
 #include "docwindow.h"
 #include "listpopupmenu.h"
 #include "statedialog.h"
@@ -24,14 +25,8 @@
 
 // kde includes
 #include <KLocalizedString>
-#if QT_VERSION < 0x050000
-#include <kinputdialog.h>
-#endif
 
 // qt includes
-#if QT_VERSION >= 0x050000
-#include <QInputDialog>
-#endif
 #include <QPointer>
 
 /**
@@ -419,10 +414,10 @@ void StateWidget::showPropertiesDialog()
 /**
  * Creates the "statewidget" XMI element.
  */
-void StateWidget::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
+void StateWidget::saveToXMI1(QDomDocument & qDoc, QDomElement & qElement)
 {
     QDomElement stateElement = qDoc.createElement(QLatin1String("statewidget"));
-    UMLWidget::saveToXMI(qDoc, stateElement);
+    UMLWidget::saveToXMI1(qDoc, stateElement);
     stateElement.setAttribute(QLatin1String("statename"), m_Text);
     stateElement.setAttribute(QLatin1String("documentation"), m_Doc);
     stateElement.setAttribute(QLatin1String("statetype"), m_stateType);
@@ -444,9 +439,9 @@ void StateWidget::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
 /**
  * Loads a "statewidget" XMI element.
  */
-bool StateWidget::loadFromXMI(QDomElement & qElement)
+bool StateWidget::loadFromXMI1(QDomElement & qElement)
 {
-    if(!UMLWidget::loadFromXMI(qElement))
+    if(!UMLWidget::loadFromXMI1(qElement))
         return false;
     m_Text = qElement.attribute(QLatin1String("statename"));
     m_Doc = qElement.attribute(QLatin1String("documentation"));
@@ -485,17 +480,10 @@ void StateWidget::slotMenuSelection(QAction* action)
     ListPopupMenu::MenuType sel = ListPopupMenu::typeFromAction(action);
     switch(sel) {
     case ListPopupMenu::mt_Rename:
-#if QT_VERSION >= 0x050000
-        nameNew = QInputDialog::getText(Q_NULLPTR,
-                                        i18n("Enter State Name"),
-                                        i18n("Enter the name of the new state:"),
-                                        QLineEdit::Normal,
-                                        name(), &ok);
-#else
-        nameNew = KInputDialog::getText(i18n("Enter State Name"),
-                                         i18n("Enter the name of the new state:"),
-                                         name(), &ok);
-#endif
+        nameNew = name();
+        ok = Dialog_Utils::askName(i18n("Enter State Name"),
+                                   i18n("Enter the name of the new state:"),
+                                   nameNew);
         if (ok && nameNew.length() > 0) {
             setName(nameNew);
         }
@@ -506,17 +494,10 @@ void StateWidget::slotMenuSelection(QAction* action)
         break;
 
     case ListPopupMenu::mt_New_Activity:
-#if QT_VERSION >= 0x050000
-        nameNew = QInputDialog::getText(Q_NULLPTR,
-                                        i18n("Enter Activity"),
-                                        i18n("Enter the name of the new activity:"),
-                                        QLineEdit::Normal,
-                                        i18n("new activity"), &ok);
-#else
-        nameNew = KInputDialog::getText(i18n("Enter Activity"),
-                                         i18n("Enter the name of the new activity:"),
-                                         i18n("new activity"), &ok);
-#endif
+        nameNew = i18n("new activity");
+        ok = Dialog_Utils::askName(i18n("Enter Activity"),
+                                   i18n("Enter the name of the new activity:"),
+                                   nameNew);
         if (ok && nameNew.length() > 0) {
             addActivity(nameNew);
         }
